@@ -263,14 +263,13 @@ def reload_pillow():
         except:
           pass
     
-    check_pillow_import()
 
 
 def check_pillow_import():
     try:
         from PIL.TiffTags import IFD
     except:
-        raise ValueError("You need to restart the runtime after installing the package. ")
+        raise ValueError("Restart the runtime. You need to restart the runtime after installing 'can-show-you-anything-ai' package. ")
 
 
 def core(
